Crate rsevents_extra

Crate rsevents_extra 

Structs

CountdownEvent
An Awaitable type that can be used to block until n parallel tasks have completed.
Semaphore
A concurrency-limiting synchronization primitive, used to limit the number of threads performing a certain operation or accessing a particular resource at the same time.
SemaphoreGuard
The concurrency token returned by Semaphore::wait(), allowing access to the concurrency-limited region/code. Gives up its slot when dropped, allowing another thread to enter the semaphore in its place.
TimeoutError
The default rsevents error for Awaitable implementations in this crate, indicating that unbounded calls to Awaitable::wait() cannot fail.

Traits

Awaitable
The rsevents abstraction over all types that can be awaited, implemented by types in this crate.